﻿using NetDocsForLLM.Models;
using System.Collections.Generic;
using System.Threading.Tasks;

namespace NetDocsForLLM.Services
{
    /// <summary>
    /// Interfaz para servicios de generación de documentación a partir de ensamblados
    /// </summary>
    public interface IDocumentationGenerator
    {
        /// <summary>
        /// Genera un modelo de documentación a partir de los ensamblados proporcionados
        /// </summary>
        /// <param name="assemblies">Ensamblados para documentar</param>
        /// <param name="settings">Configuración de exportación</param>
        /// <returns>Modelo de documentación estructurado</returns>
        Task<DocumentationModel> GenerateDocumentation(IEnumerable<AssemblyModel> assemblies, ExportSettings settings);

        /// <summary>
        /// Genera una vista previa de la documentación en formato texto (JSON o YAML)
        /// </summary>
        /// <param name="documentation">Modelo de documentación</param>
        /// <param name="settings">Configuración de exportación</param>
        /// <returns>Representación textual de la documentación</returns>
        string GenerateDocumentationPreview(DocumentationModel documentation, ExportSettings settings);
    }
}